# FEABAS

FEABAS is a python library for stitching & alignment of connectome datasets using finite-element analysis.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install FEABAS.

```bash
pip install feabas
```